#
# spec file for package kclock
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0
%define plasma6_version 5.27.80

%bcond_without  released
Name:           kclock
Version:        25.04.2
Release:        1.1
Summary:        Clock application for Plasma
License:        GPL-2.0-or-later
URL:            https://apps.kde.org/kclock
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6Kirigami) >= %{kf6_version}
BuildRequires:  cmake(KF6KirigamiAddons)
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6StatusNotifierItem) >= %{kf6_version}
BuildRequires:  cmake(Plasma) >= %{plasma6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Multimedia) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
Requires:       kirigami-addons6
Requires:       kf6-kirigami-imports >= %{kf6_version}

%description
A clock application for Plasma.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name

%files
%license LICENSES/*
%doc README.md
%{_datadir}/dbus-1/services/org.kde.kclockd.service
%{_kf6_applicationsdir}/org.kde.kclock.desktop
%{_kf6_appstreamdir}/org.kde.kclock.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.kclock_1x2.appdata.xml
%{_kf6_bindir}/kclock
%{_kf6_bindir}/kclockd
%{_kf6_configdir}/autostart/org.kde.kclockd-autostart.desktop
%{_kf6_dbusinterfacesdir}/org.kde.kclockd.Alarm.xml
%{_kf6_dbusinterfacesdir}/org.kde.kclockd.AlarmModel.xml
%{_kf6_dbusinterfacesdir}/org.kde.kclockd.KClockSettings.xml
%{_kf6_dbusinterfacesdir}/org.kde.kclockd.Timer.xml
%{_kf6_dbusinterfacesdir}/org.kde.kclockd.TimerModel.xml
%{_kf6_dbusinterfacesdir}/org.kde.kclockd.Utility.xml
%{_kf6_iconsdir}/hicolor/scalable/apps/kclock_plasmoid_1x2.svg
%{_kf6_iconsdir}/hicolor/scalable/apps/org.kde.kclock.svg
%{_kf6_notificationsdir}/kclockd.notifyrc
%dir %{_kf6_plasmadir}/plasmoids
%{_kf6_plasmadir}/plasmoids/org.kde.plasma.kclock_1x2/
%{_kf6_plugindir}/plasma/applets/org.kde.plasma.kclock_1x2.so

%files lang -f %{name}.lang

%changelog
* Tue Jun  3 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.2/
- No code change since 25.04.1
* Wed May  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.1/
- No code change since 25.04.0
* Mon Apr 14 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.0/
- No code change since 25.03.90
* Sat Mar 29 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.03.90
  * New feature release
- Changes since 24.12.3:
  * AlarmForm: create duration and snooze models correctly
  * alarmform: Fix dialogs not showing any options
  * Add xml/yaml linting
  * Port to AboutKDEPage from AboutKDE
  * Focus search box in the "Add Timezone" dialog when opened
  * Fix switching between powerdevil and wakeup polling (kde#496296)
  * Use the display name of the current timezone instead of the id
  * Set time format to "system default" if kclockd isn't running
  * Add icons to the "About KDE" and "About Clock" buttons under Settings
  * Port from Kirigami Add-ons Banner to Kirigami InlineMessage
- Drop patch:
  * 0001-AlarmForm-create-duration-and-snooze-models-correctl.patch
* Wed Mar 26 2025 Christophe Marin <christophe@krop.fr>
- Add upstream fix:
  * 0001-AlarmForm-create-duration-and-snooze-models-correctl.patch
* Tue Mar  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.3/
- No code change since 24.12.2
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- No code change since 24.12.1
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- No code change since 24.12.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- No code change since 24.11.90
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- Changes since 24.11.80:
  * Add icons to the "About KDE" and "About Clock" buttons under Settings
  * Use the display name of the current timezone instead of the id
  * Fix switching between powerdevil and wakeup polling (kde#496296)
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Changes since 24.08.3:
  * Avoid generating absolute include paths into (internal) headers
  * Don't include quiet packages in feature_summary
  * fix clang-format
  * Replace the elapsed time with remaining time (kde#479562)
  * Refactor time formatting functions
  * Remove unused code for the analog clock
  * Remove new timer drawer for mobile and use dialog (kde#492652)
  * Fix timer circle alignment (kde#481170)
  * Fix timer circle shrinking too much
  * Fix custom spinbox icons
  * Add clang-format validation job
  * Fix clang format
  * Enable KCrash also for kclockd
  * Add KCrash support
  * Call portal for autostart only in flatpak
  * Fix alarm ring popup sizing
  * Refactor wakeup code
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- No code change since 24.08.2
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- Changes since 24.08.1:
  * Fix timer circle shrinking too much
  * Fix custom spinbox icons
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- Changes since 24.08.0:
  * Fix timer circle alignment (kde#481170)
  * Call portal for autostart only in flatpak
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Changes since 24.05.2:
  * Use ecm_set_disabled_deprecation_versions
  * Improve and fix i18n
  * Move reset button to main panel on the "Stopwatch" page (kde#487989)
  * Don't build the Plasmoid in Flatpak
  * snap: update to latest release
  * Enforce passing tests on all Platforms
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- No code change since 24.05.1
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- No code change since 24.05.0
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- No code change since 24.04.80
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Changes since 24.02.2:
  * Remove warning
  * Add missing explicit keyword
  * Const'ify pointer
  * Port deprecated method
  * Remove unused includes
  * Fix qml warning
  * Add missing include moc
  * Change appdata to comply with new FlatHub guidelines
  * Update org.kde.kclock.appdata.xml
  * Remove custom appstream check
  * Fix selecting custom sound in alarm form being broken (kde#484229)
  * Port timer to play ringing sound through custom alarmplayer, rather than knotification (kde#483824)
  * Fix soundpicker page entries not selectable due to type error (kde#483453)
  * flatpak: Switch to non-preview runtime
  * appstream: Update developer name
  * appstream: Update developer name
  * ci: Use ubuntu runner
  * ci: Add tag to appstream test
  * Add backdrop icon to time page
  * stopwatch: Refactor and move laps model to C++, improve UI
  * Remove clock widget on time page
  * Fix navbar icons not showing with qqc2-breeze-style
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- Changes since 24.02.1:
  * Fix selecting custom sound in alarm form being broken (kde#484229)
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * Port timer to play ringing sound through custom alarmplayer rather than knotification (kde#483824)
  * Fix soundpicker page entries not selectable due to type error(kde#483453)
  * ci: Use ubuntu runner
  * ci: Add tag to appstream test
  * flatpak: Switch to non-preview runtime
  * CI - Flatpak: Add libplasma dependency
  * appstream: Fix developer name
  * appstream: Update developer name
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- Changes since 24.01.95:
  * Remove clock widget on time page It currently doesn't work
  * Fix navbar icons not showing with qqc2-breeze-style
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * CI: Comment out flatpak as it uses some KF6 dependencies
  * Add reuse dep5 for snapcraft file.
  * snapcraft: initial import snapcraft files.
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Changes since 23.04.3:
  * install autostart file as FILE not PROGRAM (kde#470324)
  * Remove unneeded setAssociatedWidget for tray icon
  * Enable Qt6 CI
  * Update screenshots
  * Fix add location dialog not clearing search query when reopened
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Sun Mar 19 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
